==> atmosphere-spade-server-0.6.5-sources.jar: org/atmosphere/grizzly/AtmosphereDeployer.java <==
/**
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER. *
 * Copyright 2007-2008 Sun Microsystems, Inc. All rights reserved. *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 *
 */
package org.atmosphere.grizzly;

import java.util.logging.Level;
import java.util.logging.Logger;

import org.atmosphere.grizzly.conf.AtmosphereDeployerConfiguration;

import com.sun.grizzly.http.servlet.deployer.GrizzlyWebServerDeployer;
import com.sun.grizzly.http.servlet.deployer.WarDeployer;
import com.sun.grizzly.http.servlet.deployer.conf.ConfigurationParser;
import com.sun.grizzly.http.servlet.deployer.conf.DeployerServerConfiguration;

/**
 * @author Sebastien Dionne
 */
public class AtmosphereDeployer extends GrizzlyWebServerDeployer {

    private static Logger logger = Logger.getLogger(AtmosphereDeployer.class.getName());

    private WarDeployer deployer = new AtmosphereWarDeployer();

    /**
     * @param args Command line parameters.
     */
    public static void main(String[] args) {
        new AtmosphereDeployer().launch(init(args));
    }

    public static AtmosphereDeployerConfiguration init(String args[]) {
    	AtmosphereDeployerConfiguration cfg = new AtmosphereDeployerConfiguration();
    	
        cfg = (AtmosphereDeployerConfiguration) ConfigurationParser.parseOptions(args, AtmosphereDeployer.class.getCanonicalName(), (DeployerServerConfiguration)cfg);
        if (logger.isLoggable(Level.INFO)) {
            logger.log(Level.INFO, cfg.toString());
        }
        return cfg;
    }
    
    /**
     * 
     * @return the WarDeployer instance used to deploy/undeploy applications
     */
    @Override
    protected WarDeployer getWarDeployer(){
    	return deployer;
    }
    
}

==> atmosphere-spade-server-0.7.1-sources.jar: org/atmosphere/grizzly/AtmosphereDeployer.java <==
/**
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER. *
 * Copyright 2007-2008 Sun Microsystems, Inc. All rights reserved. *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 *
 */
package org.atmosphere.grizzly;

import com.sun.grizzly.http.servlet.deployer.GrizzlyWebServerDeployer;
import com.sun.grizzly.http.servlet.deployer.WarDeployer;
import com.sun.grizzly.http.servlet.deployer.conf.ConfigurationParser;
import com.sun.grizzly.http.servlet.deployer.conf.DeployerServerConfiguration;
import org.atmosphere.grizzly.conf.AtmosphereDeployerConfiguration;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * @author Sebastien Dionne
 */
public class AtmosphereDeployer extends GrizzlyWebServerDeployer {

    private static final Logger logger = LoggerFactory.getLogger(AtmosphereDeployer.class);

    private final WarDeployer deployer = new AtmosphereWarDeployer();

    /**
     * @param args Command line parameters.
     */
    public static void main(String[] args) {
        new AtmosphereDeployer().launch(init(args));
    }

    public static AtmosphereDeployerConfiguration init(String args[]) {
    	AtmosphereDeployerConfiguration cfg = new AtmosphereDeployerConfiguration();

        cfg = (AtmosphereDeployerConfiguration) ConfigurationParser
                .parseOptions(args, AtmosphereDeployer.class.getCanonicalName(), (DeployerServerConfiguration) cfg);
        logger.info("{}", cfg.toString());
        return cfg;
    }
    
    /**
     * 
     * @return the WarDeployer instance used to deploy/undeploy applications
     */
    @Override
    protected WarDeployer getWarDeployer(){
    	return deployer;
    }
    
}
